@@ -18,6 +18,9 @@ class HTTPClient(BaseClient[MercuryHTTPClient, HTTPAction, HTTPResult]):
     def __init__(self, config: Config) -> None:
         super().__init__()
 
+        if config is None:
+            config = Config()
+
         self.session = MercuryHTTPClient(
             concurrency=config.batch_size,
             timeouts=Timeouts(
