@@ -34,16 +34,6 @@ class Hooks(Generic[A]):
         self.listeners: List[A] = []
         self.channels: List[Coroutine] = []
 
-    @property
-    def before_hook_name(self):
-        if self.before:
-            return self.before.name
-
-    @property
-    def after_hook_name(self):
-        if self.after:
-            return self.after.name
-
     @property
     def channel_hook_names(self):
         if self.channels:
@@ -81,4 +71,4 @@ class Hooks(Generic[A]):
             'notify': self.notify,
             'listen': self.listen,
             'names': self.to_names()
-        }
\ No newline at end of file
+        }
