@@ -9,14 +9,16 @@ from hedra.core.graphs.hooks.validation_types.action import ActionValidator
 from hedra.core.graphs.hooks.validation_types.after import AfterValidator
 from hedra.core.graphs.hooks.validation_types.before import BeforeValidator
 from hedra.core.graphs.hooks.validation_types.check import CheckValidator
+from hedra.core.graphs.hooks.validation_types.condition import ConditionValidator
 from hedra.core.graphs.hooks.validation_types.context import ContextValidator
 from hedra.core.graphs.hooks.validation_types.event import EventValidator
 from hedra.core.graphs.hooks.validation_types.metric import MetricValidator
-from hedra.core.graphs.hooks.validation_types.restore import RestoreValidator
+from hedra.core.graphs.hooks.validation_types.load import LoadValidator
 from hedra.core.graphs.hooks.validation_types.save import SaveValidator
 from hedra.core.graphs.hooks.validation_types.setup import SetupValidator
 from hedra.core.graphs.hooks.validation_types.task import TaskValidator
 from hedra.core.graphs.hooks.validation_types.teardown import TeardownValidator
+from hedra.core.graphs.hooks.validation_types.transform import TransformValidator
 from hedra.core.graphs.hooks.validation_types.validate import ValidateValidator
 from .registry_types import (
     ActionHook,
@@ -24,14 +26,16 @@ from .registry_types import (
     BeforeHook,
     ChannelHook,
     CheckHook,
+    ConditionHook,
     ContextHook,
     EventHook,
     MetricHook,
-    RestoreHook,
+    LoadHook,
     SaveHook,
     SetupHook,
     TaskHook,
     TeardownHook,
+    TransformHook,
     ValidateHook
 )
 
@@ -50,37 +54,39 @@ class Registrar:
             HookType.BEFORE: lambda *args, **kwargs:  BeforeHook(*args, **kwargs),
             HookType.CHANNEL: lambda *args, **kwargs:  ChannelHook(*args, **kwargs),
             HookType.CHECK: lambda *args, **kwargs:  CheckHook(*args, **kwargs),
+            HookType.CONDITION: lambda *args, **kwargs: ConditionHook(*args, **kwargs),
             HookType.CONTEXT: lambda *args, **kwargs:  ContextHook(*args, **kwargs),
             HookType.EVENT: lambda *args, **kwargs:  EventHook(*args, **kwargs),
             HookType.METRIC: lambda *args, **kwargs:  MetricHook(*args, **kwargs),
-            HookType.RESTORE: lambda *args, **kwargs:  RestoreHook(*args, **kwargs),
+            HookType.LOAD: lambda *args, **kwargs:  LoadHook(*args, **kwargs),
             HookType.SAVE: lambda *args, **kwargs:  SaveHook(*args, **kwargs),
             HookType.SETUP: lambda *args, **kwargs:  SetupHook(*args, **kwargs),
             HookType.TASK: lambda *args, **kwargs:  TaskHook(*args, **kwargs),
             HookType.TEARDOWN: lambda *args, **kwargs:  TeardownHook(*args, **kwargs),
+            HookType.TRANSFORM: lambda *args, **kwargs: TransformHook(*args, **kwargs),
             HookType.VALIDATE: lambda *args, **kwargs:  ValidateHook(*args, **kwargs)
         }
 
         self.validator_types = {
-            HookType.ACTION: ActionValidator,
+            HookType.ACTION: lambda *args, **kwargs: ActionValidator(*args, **kwargs),
             HookType.AFTER: lambda *args, **kwargs: AfterValidator(*args, **kwargs),
             HookType.BEFORE: lambda *args, **kwargs: BeforeValidator(*args, **kwargs),
             HookType.CHECK: lambda *args, **kwargs: CheckValidator(*args, **kwargs),
-            HookType.CONTEXT: ContextValidator,
+            HookType.CONDITION: lambda *args, **kwargs: ConditionValidator(*args, **kwargs),
+            HookType.CONTEXT: lambda *args, **kwargs: ContextValidator(*args, **kwargs),
             HookType.EVENT: lambda *args, **kwargs: EventValidator(*args, **kwargs),
             HookType.METRIC: lambda *args, **kwargs: MetricValidator(*args, **kwargs),
-            HookType.RESTORE: lambda *args, **kwargs: RestoreValidator(*args, **kwargs),
+            HookType.LOAD: lambda *args, **kwargs: LoadValidator(*args, **kwargs),
             HookType.SAVE: lambda *args, **kwargs: SaveValidator(*args, **kwargs),
             HookType.SETUP: lambda *args, **kwargs: SetupValidator(*args, **kwargs),
             HookType.TASK: lambda *args, **kwargs: TaskValidator(*args, **kwargs),
             HookType.TEARDOWN: lambda *args, **kwargs: TeardownValidator(*args, **kwargs),
+            HookType.TRANSFORM: lambda *args, **kwargs: TransformValidator(*args, **kwargs),
             HookType.VALIDATE: lambda *args, **kwargs: ValidateValidator(*args, **kwargs),
         }
 
 
     def __call__(self, hook: FunctionType):
-
-  
         self.module_paths[hook.__name__] = hook.__module__
 
         @functools.wraps(hook)
@@ -90,7 +96,6 @@ class Registrar:
 
                 hook_name = func.__qualname__
                 hook_shortname = func.__name__
-
                 hook = self.hook_types[self.hook_type]
 
                 hook_args = args
@@ -108,14 +113,25 @@ class Registrar:
                     except TypeError as e:
                         raise e
                         
+                if hook_name not in self.all:
+                    self.all[hook_name] = [
+                        hook(
+                            hook_name,
+                            hook_shortname,
+                            func,
+                            *hook_args,
+                            **kwargs
+                        )
+                    ]
 
-                self.all[hook_name] = hook(
-                    hook_name,
-                    hook_shortname,
-                    func,
-                    *hook_args,
-                    **kwargs
-                )
+                else:
+                    self.all[hook_name].append(hook(
+                        hook_name,
+                        hook_shortname,
+                        func,
+                        *hook_args,
+                        **kwargs
+                    ))
 
                 return func
             
