@@ -1,9 +1,10 @@
 from typing import Tuple
-from pydantic import BaseModel, validator, StrictStr
+from pydantic import BaseModel, validator, StrictStr, StrictInt
 
 
 class CheckHookValidator(BaseModel):
     names: Tuple[StrictStr, ...]
+    order: StrictInt
 
     @validator('names')
     def validate_names(cls, vals):
@@ -14,7 +15,8 @@ class CheckHookValidator(BaseModel):
 class CheckValidator:
     names: Tuple[str, ...]
 
-    def __init__(__pydantic_self__, *names: Tuple[str, ...]) -> None:
+    def __init__(__pydantic_self__, *names: Tuple[str, ...], order: int=1) -> None:
         CheckHookValidator(
-            names=names
+            names=names,
+            order=order
         )
\ No newline at end of file
