@@ -1,5 +1,6 @@
+from typing import Union
 from hedra.core.graphs.hooks.hook_types.hook_type import HookType
-from hedra.core.graphs.events.event import Event
+from hedra.core.graphs.events.base_event import BaseEvent
 from hedra.core.graphs.hooks.registry.registry_types import SetupHook
 from hedra.core.graphs.stages.validate.exceptions import HookValidationError
 from .base_hook_validator import BaseHookVaidator
@@ -13,12 +14,12 @@ class SetupHookVaidator(BaseHookVaidator):
             self
         ).__init__(metadata_string)
 
-    async def validate(self, hook: SetupHook):
+    async def validate(self, hook: Union[SetupHook, BaseEvent]):
 
         try:
             
             call = hook._call
-            if isinstance(hook, Event):
+            if isinstance(hook, BaseEvent):
                 call = hook.target._call
 
             await self.logger.filesystem.aio['hedra.core'].debug(f'{self.metadata_string} - Validating {hook.hook_type.name.capitalize()} Hook - {hook.name}:{hook.hook_id}:{hook.hook_id}')
@@ -29,7 +30,7 @@ class SetupHookVaidator(BaseHookVaidator):
             assert call.__code__.co_argcount > 0, f"Too few args. - @setup hook {hook.name}:{hook.hook_id} requires no additional args."
             assert call.__code__.co_argcount < 2, f"Too many args. - @setup hook {hook.name}:{hook.hook_id} requires no additional args"
 
-            assert 'self' in hook.call.__code__.co_varnames
+            assert 'self' in hook._call.__code__.co_varnames
 
             
             await self.logger.filesystem.aio['hedra.core'].debug(f'{self.metadata_string} - Validated {hook.hook_type.name.capitalize()} Hook - {hook.name}:{hook.hook_id}:{hook.hook_id}')
