@@ -3,7 +3,7 @@ import uuid
 from typing import List
 
 from numpy import float32, float64, int16, int32, int64
-from hedra.reporting.events.types.base_result import BaseEvent
+from hedra.reporting.processed_result.types.base_processed_result import BaseProcessedResult
 from hedra.reporting.metric import MetricsSet
 
 
@@ -30,7 +30,7 @@ class TimescaleDB(Postgres):
     def __init__(self, config: TimescaleDBConfig) -> None:
         super().__init__(config)
 
-    async def submit_events(self, events: List[BaseEvent]):
+    async def submit_events(self, events: List[BaseProcessedResult]):
 
         await self.logger.filesystem.aio['hedra.reporting'].info(f'{self.metadata_string} - Submitting Events to Table - {self.events_table_name}')
 
